@@ -13,8 +13,6 @@ from nvchecker.api import (
 GITLAB_URL = 'https://%s/api/v4/projects/%s/repository/commits'
 GITLAB_MAX_TAG = 'https://%s/api/v4/projects/%s/repository/tags'
 
-logger = structlog.get_logger(logger_name=__name__)
-
 async def get_version(name, conf, **kwargs):
   try:
     return await get_version_real(name, conf, **kwargs)
@@ -70,11 +68,11 @@ def check_ratelimit(exc, name):
   if not res:
     raise
 
+  logger = structlog.get_logger(logger_name=__name__, name=name)
   # default -1 is used to re-raise the exception
   n = int(res.headers.get('RateLimit-Remaining', -1))
   if n == 0:
     logger.error('gitlab rate limited. Wait some time '
-                 'or get an API token to increase the allowance if not yet',
-                 name = name)
+                 'or get an API token to increase the allowance if not yet')
   else:
     raise
