@@ -1,24 +1,32 @@
 # MIT licensed
-# Copyright (c) 2020 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2020, 2024 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import asyncio
 import structlog
 import os
 from pathlib import Path
+from typing import TYPE_CHECKING, Dict
+
+if TYPE_CHECKING:
+  import tomli as tomllib
+else:
+  try:
+    import tomllib
+  except ModuleNotFoundError:
+    import tomli as tomllib
 
-import tomli
 import pytest
 import pytest_asyncio
 
 from nvchecker import core
 from nvchecker import __main__ as main
-from nvchecker.util import Entries, VersData, RawResult
+from nvchecker.util import Entries, ResultData, RawResult
 
 use_keyfile = False
 
 async def run(
   entries: Entries, max_concurrency: int = 20,
-) -> VersData:
+) -> Dict[str, str]:
   task_sem = asyncio.Semaphore(max_concurrency)
   result_q: asyncio.Queue[RawResult] = asyncio.Queue()
   keyfile = os.environ.get('KEYFILE')
@@ -35,14 +43,14 @@ async def run(
     keymanager, entry_waiter, 1, {},
   )
 
-  oldvers: VersData = {}
+  oldvers: ResultData = {}
   result_coro = core.process_result(oldvers, result_q, entry_waiter)
   runner_coro = core.run_tasks(futures)
 
-  vers, _has_failures = await main.run(result_coro, runner_coro)
-  return vers
+  results, _has_failures = await main.run(result_coro, runner_coro)
+  return {k: r.version for k, r in results.items()}
 
-@pytest_asyncio.fixture(scope="module")
+@pytest_asyncio.fixture(scope="session")
 async def get_version():
   async def __call__(name, config):
     entries = {name: config}
@@ -51,33 +59,24 @@ async def get_version():
 
   return __call__
 
-@pytest_asyncio.fixture(scope="module")
+@pytest_asyncio.fixture(scope="session")
 async def run_str():
   async def __call__(str):
-    entries = tomli.loads(str)
+    entries = tomllib.loads(str)
     newvers = await run(entries)
     return newvers.popitem()[1]
 
   return __call__
 
-@pytest_asyncio.fixture(scope="module")
+@pytest_asyncio.fixture(scope="session")
 async def run_str_multi():
   async def __call__(str):
-    entries = tomli.loads(str)
+    entries = tomllib.loads(str)
     newvers = await run(entries)
     return newvers
 
   return __call__
 
-loop = asyncio.new_event_loop()
-@pytest.fixture(scope="session")
-def event_loop(request):
-  """Override pytest-asyncio's event_loop fixture,
-     Don't create an instance of the default event loop for each test case.
-     We need the same ioloop across tests for the aiohttp support.
-  """
-  yield loop
-
 @pytest.fixture(scope="session", autouse=True)
 def raise_on_logger_msg():
   def proc(logger, method_name, event_dict):
