@@ -2,7 +2,7 @@
 # Copyright (c) 2020 Felix Yan <felixonmars@archlinux.org>, et al.
 
 import pytest
-pytestmark = [pytest.mark.asyncio(scope="session"), pytest.mark.needs_net]
+pytestmark = [pytest.mark.asyncio, pytest.mark.needs_net]
 
 async def test_git(get_version):
     assert await get_version("example", {
