@@ -3,10 +3,11 @@
 
 import pytest
 pytestmark = [
-  pytest.mark.asyncio(scope="session"),
+  pytest.mark.asyncio,
   pytest.mark.needs_net,
 ]
 
+@pytest.mark.skip
 async def test_mercurial(get_version):
   assert await get_version("example", {
     "source": "mercurial",
