@@ -2,7 +2,7 @@
 # Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import pytest
-pytestmark = [pytest.mark.asyncio(scope="session"), pytest.mark.needs_net]
+pytestmark = [pytest.mark.asyncio, pytest.mark.needs_net]
 
 async def test_pypi(get_version):
     assert await get_version("example", {
@@ -25,10 +25,15 @@ async def test_pypi_list(get_version):
     assert await get_version("urllib3", {
         "source": "pypi",
         "include_regex": "^1\\..*",
-    }) == "1.26.18"
+    }) == "1.26.20"
 
 async def test_pypi_invalid_version(get_version):
     await get_version("sympy", {
         "source": "pypi",
     })
 
+async def test_pypi_yanked_version(get_version):
+    assert await get_version("urllib3", {
+        "source": "pypi",
+        "include_regex": "^(1\\..*)|(2\\.0\\.[0,1])",
+    }) == "1.26.20"
