@@ -2,21 +2,19 @@
 # Copyright (c) 2019-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import pytest
-pytestmark = [pytest.mark.asyncio(scope="session"),
+pytestmark = [pytest.mark.asyncio,
               pytest.mark.needs_net]
 
-@pytest.mark.flaky(reruns=10)
 async def test_repology(get_version):
   assert await get_version("ssed", {
         "source": "repology",
         "repo": "aur",
   }) == "3.62"
 
-@pytest.mark.flaky(reruns=10)
 async def test_repology_subrepo(get_version):
   assert await get_version("asciiquarium", {
         "source": "repology",
-        "repo": "fedora_32",
+        "repo": "fedora_42",
         "subrepo": "release"
   }) == "1.1"
 
@@ -24,7 +22,7 @@ async def test_repology_bad_subrepo(get_version):
   try:
     assert await get_version("asciiquarium", {
             "source": "repology",
-            "repo": "fedora_32",
+            "repo": "fedora_42",
             "subrepo": "badsubrepo"
     }) is None
   except RuntimeError as e:
