@@ -7,13 +7,13 @@ pytestmark = [pytest.mark.asyncio, pytest.mark.needs_net]
 async def test_rpmrepo_fedora(get_version):
     assert await get_version("knot_fedora-39", {
         "source": "rpmrepo",
-        "pkg": "knot",
-        "repo": "http://ftp.sh.cvut.cz/fedora/linux/updates/39/Everything/x86_64/",
-    }) == "3.3.9"
+        "pkg": "libbtrfs",
+        "repo": "https://ftp.sh.cvut.cz/fedora/linux/updates/42/Everything/x86_64/",
+    }) == "6.16"
 
 async def test_rpmrepo_alma(get_version):
-    assert await get_version("knot_fedora-39", {
+    assert await get_version("test", {
         "source": "rpmrepo",
-        "pkg": "tmux",
-        "repo": "http://ftp.sh.cvut.cz/almalinux/9.5/BaseOS/x86_64/os/",
-    }) == "3.2a"
+        "pkg": "readline",
+        "repo": "http://ftp.sh.cvut.cz/almalinux/9/BaseOS/x86_64/os/",
+    }) == "8.1"
